@@ -101,6 +101,6 @@ def main():
         else:
             print(f"Have successfully installed {args.package}. You can access it by running {args.package} on the command line.")
             if PLATFORM == 'windows':
-                print(f"\nPlease restart Powershell to update your PATH variable so that it includes {args.package}")
+                print(f"\nPlease restart your computer to update your PATH variable so that it includes {args.package}")
             else:
                 print(f"\nIf {args.package} does not work in terminal, please make sure that /usr/local/bin is on your PATH variable.")
